@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-__author__ = "Giovani Hidalgo Ceotto"
+__author__ = "Giovani Hidalgo Ceotto, Oscar Mauricio Prada Ramirez"
 __copyright__ = "Copyright 20XX, Projeto Jupiter"
 __license__ = "MIT"
 
@@ -24,7 +24,7 @@ from .Function import Function
 
 
 class SolidMotor:
-    """Class to specify characteriscts and useful operations for solid
+    """Class to specify characteristics and useful operations for solid
     motors.
 
     Attributes
@@ -36,7 +36,7 @@ class SolidMotor:
         Motor.throatRadius : float
             Radius of motor nozzle throat in meters.
         Motor.grainNumber : int
-            Number os solid grains.
+            Number of solid grains.
         Motor.grainSeparation : float
             Distance between two grains in meters.
         Motor.grainDensity : float
@@ -91,7 +91,7 @@ class SolidMotor:
             Average thrust of the motor, given in N.
         Motor.burnOutTime : float
             Total motor burn out time, in seconds. Must include delay time
-            when motor takes time to ignite. Also seen as time to end thrust
+            when the motor takes time to ignite. Also seen as time to end thrust
             curve.
         Motor.exhaustVelocity : float
             Propulsion gases exhaust velocity, assumed constant, in m/s.
@@ -132,14 +132,14 @@ class SolidMotor:
         ----------
         thrustSource : int, float, callable, string, array
             Motor's thrust curve. Can be given as an int or float, in which
-            case the thrust will be considerared constant in time. It can
+            case the thrust will be considered constant in time. It can
             also be given as a callable function, whose argument is time in
             seconds and returns the thrust supplied by the motor in the
             instant. If a string is given, it must point to a .csv or .eng file.
             The .csv file shall contain no headers and the first column must
             specify time in seconds, while the second column specifies thrust.
             Arrays may also be specified, following rules set by the class
-            Function. See help(Function). Thrust units is Newtons.
+            Function. See help(Function). Thrust units are Newtons.
         burnOut : int, float
             Motor burn out time in seconds.
         grainNumber : int
@@ -156,7 +156,7 @@ class SolidMotor:
             Distance between grains, in meters. Default is 0.
         nozzleRadius : int, float, optional
             Motor's nozzle outlet radius in meters. Used to calculate Kn curve.
-            Optional if Kn curve is not if intereste. Its value does not impact
+            Optional if the Kn curve is not interesting. Its value does not impact
             trajectory simulation.
         throatRadius : int, float, optional
             Motor's nozzle throat radius in meters. Its value has very low
@@ -228,7 +228,6 @@ class SolidMotor:
         self.grainInitialInnerRadius = grainInitialInnerRadius
         self.grainInitialHeight = grainInitialHeight
         # Other quantities that will be computed
-        self.exhaustVelocity = None
         self.massDot = None
         self.mass = None
         self.grainInnerRadius = None
@@ -239,12 +238,12 @@ class SolidMotor:
         self.inertiaI = None
         self.inertiaIDot = None
         self.inertiaZ = None
-        self.inertiaDot = None
+        self.inertiaZDot = None
         self.maxThrust = None
         self.maxThrustTime = None
         self.averageThrust = None
 
-        # Compute uncalculated quantities
+        # Compute quantities
         # Thrust information - maximum and average
         self.maxThrust = np.amax(self.thrust.source[:, 1])
         maxThrustIndex = np.argmax(self.thrust.source[:, 1])
@@ -259,7 +258,6 @@ class SolidMotor:
         self.grainInitialMass = self.grainDensity * self.grainInitialVolume
         self.propellantInitialMass = self.grainNumber * self.grainInitialMass
         # Dynamic quantities
-        self.evaluateExhaustVelocity()
         self.evaluateMassDot()
         self.evaluateMass()
         self.evaluateGeometry()
@@ -271,7 +269,7 @@ class SolidMotor:
         """Transforms the thrust curve supplied by changing its total
         burn time and/or its total impulse, without altering the
         general shape of the curve. May translate the curve so that
-        thrust starts at time equals 0, with out any delays.
+        thrust starts at time equals 0, without any delays.
 
         Parameters
         ----------
@@ -297,7 +295,6 @@ class SolidMotor:
         # Retrieve current thrust curve data points
         timeArray = self.thrust.source[:, 0]
         thrustArray = self.thrust.source[:, 1]
-
         # Move start to time = 0
         if startAtZero and timeArray[0] != 0:
             timeArray = timeArray - timeArray[0]
@@ -339,7 +336,8 @@ class SolidMotor:
         # Return total impulse
         return self.totalImpulse
 
-    def evaluateExhaustVelocity(self):
+    @property
+    def exhaustVelocity(self):
         """Calculates and returns exhaust velocity by assuming it
         as a constant. The formula used is total impulse/propellant
         initial mass. The value is also stored in
@@ -354,15 +352,7 @@ class SolidMotor:
         self.exhaustVelocity : float
             Constant gas exhaust velocity of the motor.
         """
-        # Calculate total impulse if not yet done so
-        if self.totalImpulse is None:
-            self.evaluateTotalImpulse()
-
-        # Calculate exhaust velocity
-        self.exhaustVelocity = self.totalImpulse / self.propellantInitialMass
-
-        # Return exhaust velocity
-        return self.exhaustVelocity
+        return self.totalImpulse / self.propellantInitialMass
 
     def evaluateMassDot(self):
         """Calculates and returns the time derivative of propellant
@@ -381,10 +371,6 @@ class SolidMotor:
             Time derivative of total propellant mas as a function
             of time.
         """
-        # Calculate exhaust velocity if not done so already
-        if self.exhaustVelocity is None:
-            self.evaluateExhaustVelocity()
-
         # Create mass dot Function
         self.massDot = self.thrust / (-self.exhaustVelocity)
         self.massDot.setOutputs("Mass Dot (kg/s)")
@@ -435,6 +421,10 @@ class SolidMotor:
         # Return Mass Function
         return self.mass
 
+    @property
+    def throatArea(self):
+        return np.pi * self.throatRadius ** 2
+
     def evaluateGeometry(self):
         """Calculates grain inner radius and grain height as a
         function of time by assuming that every propellant mass
@@ -464,10 +454,10 @@ class SolidMotor:
         # Define time mesh
         t = self.massDot.source[:, 0]
 
-        # Define system of differential equations
         density = self.grainDensity
         rO = self.grainOuterRadius
 
+        # Define system of differential equations
         def geometryDot(y, t):
             grainMassDot = self.massDot(t) / self.grainNumber
             rI, h = y
@@ -497,7 +487,26 @@ class SolidMotor:
         )
 
         # Create functions describing burn rate, Kn and burn area
-        # Burn Area
+        self.evaluateBurnArea()
+        self.evaluateKn()
+        self.evaluateBurnRate()
+
+        return [self.grainInnerRadius, self.grainHeight]
+
+    def evaluateBurnArea(self):
+        """Calculates the BurnArea of the grain for
+        each time. Assuming that the grains are cylindrical
+        BATES grains.
+
+        Parameters
+        ----------
+        None
+
+        Returns
+        -------
+        burnArea : Function
+        Function representing the burn area progression with the time.
+        """
         self.burnArea = (
             2
             * np.pi
@@ -509,13 +518,32 @@ class SolidMotor:
             * self.grainNumber
         )
         self.burnArea.setOutputs("Burn Area (m2)")
-        # Kn
-        throatArea = np.pi * (self.throatRadius) ** 2
+        return self.burnArea
+
+    def evaluateBurnRate(self):
+        """Calculates the BurnRate with respect to time.
+        This evaluation assumes that it was already
+        calculated the massDot, burnArea timeseries.
+
+        Parameters
+        ----------
+        None
+
+        Returns
+        -------
+        burnRate : Function
+        Rate of progression of the inner radius during the combustion.
+        """
+        self.burnRate = (-1) * self.massDot / (self.burnArea * self.grainDensity)
+        self.burnRate.setOutputs("Burn Rate (m/s)")
+        return self.burnRate
+
+    def evaluateKn(self):
         KnSource = (
             np.concatenate(
                 (
                     [self.grainInnerRadius.source[:, 1]],
-                    [self.burnArea.source[:, 1] / throatArea],
+                    [self.burnArea.source[:, 1] / self.throatArea],
                 )
             ).transpose()
         ).tolist()
@@ -526,11 +554,7 @@ class SolidMotor:
             self.interpolate,
             "constant",
         )
-        # Burn Rate
-        self.burnRate = (-1) * self.massDot / (self.burnArea * self.grainDensity)
-        self.burnRate.setOutputs("Burn Rate (m/s)")
-
-        return [self.grainInnerRadius, self.grainHeight]
+        return self.Kn
 
     def evaluateInertia(self):
         """Calculates propellant inertia I, relative to directions
@@ -565,11 +589,11 @@ class SolidMotor:
 
         # Calculate each grain's distance d to propellant center of mass
         initialValue = (grainNumber - 1) / 2
-        d = np.linspace(-initialValue, initialValue, self.grainNumber)
+        d = np.linspace(-initialValue, initialValue, grainNumber)
         d = d * (self.grainInitialHeight + self.grainSeparation)
 
         # Calculate inertia for all grains
-        self.inertiaI = grainNumber * (grainInertiaI) + grainMass * np.sum(d ** 2)
+        self.inertiaI = grainNumber * grainInertiaI + grainMass * np.sum(d ** 2)
         self.inertiaI.setOutputs("Propellant Inertia I (kg*m2)")
 
         # Inertia I Dot
@@ -586,7 +610,7 @@ class SolidMotor:
         )
 
         # Calculate inertia I dot for all grains
-        self.inertiaIDot = grainNumber * (grainInertiaIDot) + grainMassDot * np.sum(
+        self.inertiaIDot = grainNumber * grainInertiaIDot + grainMassDot * np.sum(
             d ** 2
         )
         self.inertiaIDot.setOutputs("Propellant Inertia I Dot (kg*m2/s)")
@@ -600,11 +624,9 @@ class SolidMotor:
         self.inertiaZ.setOutputs("Propellant Inertia Z (kg*m2)")
 
         # Inertia Z Dot
-        self.inertiaZDot = (
-            (1 / 2.0) * (self.massDot * self.grainOuterRadius ** 2)
-            + (1 / 2.0) * (self.massDot * self.grainInnerRadius ** 2)
-            + self.mass * self.grainInnerRadius * self.burnRate
-        )
+        self.inertiaZDot = (1 / 2.0) * self.massDot * (
+            self.grainOuterRadius ** 2 + self.grainInnerRadius ** 2
+        ) + self.mass * self.grainInnerRadius * self.burnRate
         self.inertiaZDot.setOutputs("Propellant Inertia Z Dot (kg*m2/s)")
 
         return [self.inertiaI, self.inertiaZ]
@@ -622,17 +644,17 @@ class SolidMotor:
         Returns
         -------
         comments : list
-            All comments in the .eng file, separeted by line in a list. Each
+            All comments in the .eng file, separated by line in a list. Each
             line is an entry of the list.
         description: list
-            Description of the motor. All attributes are returned separeted in
+            Description of the motor. All attributes are returned separated in
             a list. E.g. "F32 24 124 5-10-15 .0377 .0695 RV\n" is return as
             ['F32', '24', '124', '5-10-15', '.0377', '.0695', 'RV\n']
         dataPoints: list
             List of all data points in file. Each data point is an entry in
             the returned list and written as a list of two entries.
         """
-        # Intiailize arrays
+        # Initialize arrays
         comments = []
         description = []
         dataPoints = [[0, 0]]
@@ -640,13 +662,14 @@ class SolidMotor:
         # Open and read .eng file
         with open(fileName) as file:
             for line in file:
-                if line[0] == ";":
+                if re.search(r";.*", line):
                     # Extract comment
-                    comments.append(line)
-                else:
+                    comments.append(re.findall(r";.*", line)[0])
+                    line = re.sub(r";.*", "", line)
+                if line.strip():
                     if description == []:
                         # Extract description
-                        description = line.split(" ")
+                        description = line.strip().split(" ")
                     else:
                         # Extract thrust curve data points
                         time, thrust = re.findall(r"[-+]?\d*\.\d+|[-+]?\d+", line)
@@ -678,7 +701,7 @@ class SolidMotor:
         # Write first line
         file.write(
             motorName
-            + " {:3.1f} {:3.1f} 0 {:2.3} {:2.3} PJ \n".format(
+            + " {:3.1f} {:3.1f} 0 {:2.3} {:2.3} RocketPy\n".format(
                 2000 * self.grainOuterRadius,
                 1000
                 * self.grainNumber
@@ -689,9 +712,8 @@ class SolidMotor:
         )
 
         # Write thrust curve data points
-        for item in self.thrust.source[:-1, :]:
-            time = item[0]
-            thrust = item[1]
+        for time, thrust in self.thrust.source[1:-1, :]:
+            # time, thrust = item
             file.write("{:.4f} {:.3f}\n".format(time, thrust))
 
         # Write last line
